aboutsummaryrefslogtreecommitdiff
path: root/gas
diff options
context:
space:
mode:
authorDoug Evans <dje@google.com>1998-06-02 16:26:43 +0000
committerDoug Evans <dje@google.com>1998-06-02 16:26:43 +0000
commit83e207013b0ff74a936079ac66fba09ce485d102 (patch)
treed95bbada0a16bb84f693aacaf702a7d1cb0d81d6 /gas
parent33c65ba3b304c0b26899385fae3987b95c70d4f4 (diff)
downloadfsf-binutils-gdb-83e207013b0ff74a936079ac66fba09ce485d102.zip
fsf-binutils-gdb-83e207013b0ff74a936079ac66fba09ce485d102.tar.gz
fsf-binutils-gdb-83e207013b0ff74a936079ac66fba09ce485d102.tar.bz2
* read.c (s_func): Prepend `leading char' by default.
Diffstat (limited to 'gas')
-rw-r--r--gas/ChangeLog4
-rw-r--r--gas/read.c12
2 files changed, 14 insertions, 2 deletions
diff --git a/gas/ChangeLog b/gas/ChangeLog
index edc31ef..a3f8ee6 100644
--- a/gas/ChangeLog
+++ b/gas/ChangeLog
@@ -1,3 +1,7 @@
+Tue Jun 2 09:25:34 1998 Doug Evans <devans@canuck.cygnus.com>
+
+ * read.c (s_func): Prepend `leading char' by default.
+
start-sanitize-r5900
Mon Jun 1 17:04:56 1998 Jeffrey A Law (law@cygnus.com)
diff --git a/gas/read.c b/gas/read.c
index f4746dc..61a37cb 100644
--- a/gas/read.c
+++ b/gas/read.c
@@ -4960,8 +4960,16 @@ s_func (end_p)
SKIP_WHITESPACE ();
if (*input_line_pointer != ',')
{
- /* Missing entry point, use function's name. */
- label = name;
+ char leading_char = 0;
+#ifdef BFD_ASSEMBLER
+ leading_char = bfd_get_symbol_leading_char (stdoutput);
+#endif
+ /* Missing entry point, use function's name with the leading
+ char prepended. */
+ if (leading_char)
+ asprintf (&label, "%c%s", leading_char, name);
+ else
+ label = name;
}
else
{